package com.ruoyi.cs.service;

import java.util.List;
import com.ruoyi.cs.domain.CsWorkloadRecord;

/**
 * 人员工作量记录Service接口
 * 
 * @author ruoyi
 * @date 2024-05-31
 */
public interface ICsWorkloadRecordService 
{
    /**
     * 查询人员工作量记录
     * 
     * @param workloadRecordId 人员工作量记录主键
     * @return 人员工作量记录
     */
    public CsWorkloadRecord selectCsWorkloadRecordByWorkloadRecordId(String workloadRecordId);

    /**
     * 查询人员工作量记录列表
     * 
     * @param csWorkloadRecord 人员工作量记录
     * @return 人员工作量记录集合
     */
    public List<CsWorkloadRecord> selectCsWorkloadRecordList(CsWorkloadRecord csWorkloadRecord);

    /**
     * 新增人员工作量记录
     * 
     * @param csWorkloadRecord 人员工作量记录
     * @return 结果
     */
    public int insertCsWorkloadRecord(CsWorkloadRecord csWorkloadRecord);

    /**
     * 修改人员工作量记录
     * 
     * @param csWorkloadRecord 人员工作量记录
     * @return 结果
     */
    public int updateCsWorkloadRecord(CsWorkloadRecord csWorkloadRecord);

    /**
     * 批量删除人员工作量记录
     * 
     * @param workloadRecordIds 需要删除的人员工作量记录主键集合
     * @return 结果
     */
    public int deleteCsWorkloadRecordByWorkloadRecordIds(String[] workloadRecordIds);

    /**
     * 删除人员工作量记录信息
     * 
     * @param workloadRecordId 人员工作量记录主键
     * @return 结果
     */
    public int deleteCsWorkloadRecordByWorkloadRecordId(String workloadRecordId);
}
